//*****************************************************************************
//*****************************************************************************
//  FILENAME: CAN.h
//   Version: 3.2, Updated on 2011/6/28 at 6:9:4
//
//  DESCRIPTION:  C declarations for the DELSIG8 User Module with
//                a 1st-order modulator.
//-----------------------------------------------------------------------------
//      Copyright (c) Cypress Semiconductor 2011. All Rights Reserved.
//*****************************************************************************
//*****************************************************************************
#ifndef CAN_INCLUDE
#define CAN_INCLUDE

#include <m8c.h>

#define CAN_POLL_ENABLE 1

#pragma fastcall16 CAN_Start
#pragma fastcall16 CAN_SetPower
#pragma fastcall16 CAN_StartAD
#pragma fastcall16 CAN_StopAD
#pragma fastcall16 CAN_Stop

#if ( CAN_POLL_ENABLE )
#pragma fastcall16 CAN_fIsDataAvailable
#pragma fastcall16 CAN_cGetData
#pragma fastcall16 CAN_cGetDataClearFlag
#pragma fastcall16 CAN_ClearFlag
#endif

//-------------------------------------------------
// Prototypes of the CAN API.
//-------------------------------------------------
extern void CAN_Start(BYTE bPower);       // RAM use class 2
extern void CAN_SetPower(BYTE bPower);    // RAM use class 2
extern void CAN_StartAD(void);            // RAM use class 1
extern void CAN_StopAD(void);             // RAM use class 1
extern void CAN_Stop(void);               // RAM use class 1

#if ( CAN_POLL_ENABLE )
extern BYTE CAN_fIsDataAvailable(void);   // RAM use class 4
extern CHAR CAN_cGetData(void);           // RAM use class 4
extern CHAR CAN_cGetDataClearFlag(void);  // RAM use class 4
extern void CAN_ClearFlag(void);          // RAM use class 4
#endif

//-------------------------------------------------
// Defines for CAN API's.
//-------------------------------------------------
#define CAN_OFF         0
#define CAN_LOWPOWER    1
#define CAN_MEDPOWER    2
#define CAN_HIGHPOWER   3

#define CAN_DATA_READY_BIT  0x10
//-------------------------------------------------
// Hardware Register Definitions
//-------------------------------------------------
#pragma ioport  CAN_TimerDR0:   0x020              //Time base Counter register
BYTE            CAN_TimerDR0;
#pragma ioport  CAN_TimerDR1:   0x021              //Time base Period value register
BYTE            CAN_TimerDR1;
#pragma ioport  CAN_TimerDR2:   0x022              //Time base CompareValue register
BYTE            CAN_TimerDR2;
#pragma ioport  CAN_TimerCR0:   0x023              //Time base Control register
BYTE            CAN_TimerCR0;
#pragma ioport  CAN_TimerFN:    0x120               //Time base Function register
BYTE            CAN_TimerFN;
#pragma ioport  CAN_TimerSL:    0x121               //Time base Input register
BYTE            CAN_TimerSL;
#pragma ioport  CAN_TimerOS:    0x122               //Time base Output register
BYTE            CAN_TimerOS;

#pragma ioport  CAN_AtoDcr0:    0x080               //Analog control register 0
BYTE            CAN_AtoDcr0;
#pragma ioport  CAN_AtoDcr1:    0x081               //Analog control register 1
BYTE            CAN_AtoDcr1;
#pragma ioport  CAN_AtoDcr2:    0x082               //Analog control register 2
BYTE            CAN_AtoDcr2;
#pragma ioport  CAN_AtoDcr3:    0x083               //Analog control register 3
BYTE            CAN_AtoDcr3;

#endif
// end of file CAN.h
